ValueShapeValidator

Trait ValueShapeValidator 

pub trait ValueShapeValidator {
    // Required method
    fn accepts(&self, domain: &DomainId, value: &Datum) -> bool;
}
Injected runtime boundary for checking a Datum through a domain Shape.

Required Methods

fn accepts(&self, domain: &DomainId, value: &Datum) -> bool

Returns whether value satisfies the Shape registered for domain.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors